/*
  Connections:
    power source for sensors and display - D12
    OLED Display - SH110X :
      3.3V  - VCC
      A4  - SDA
      A5  - SCL
      GND - GND
    Temperature Sensor - LM34 :     (facing flat side, left to right)
      D12 - PIN 1 (POWER)
      A0  - PIN 2
      GND - PIN 3
    Distance Sensor - HC-SR04 :
      D12  -  VCC
      D3  - Trig
      D2  - Echo
      GND - GND
    Motion Sensor - HC-SR501 :
      D12 - POWER 
      D4 - INPUT PIN (MIDDLE)
    LEDs :
      LED 1 INPUT : D6
*/

#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SH110X.h>
#include <stdio.h>
#define echoPin 2 
#define trigPin 3 
int distance; 
#define powerpin 12 //power source pin
#define motionsensor 4 
#define ledpin 9
#define i2c_Address 0x3c 
#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels
#define OLED_RESET -1  
Adafruit_SH1106G display = Adafruit_SH1106G(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);
#define NUMFLAKES 10
#define XPOS 0
#define YPOS 1
#define DELTAY 2
#define LOGO16_GLCD_HEIGHT 16
#define LOGO16_GLCD_WIDTH  16

static const unsigned char PROGMEM logo16_glcd_bmp[] =
{ B00000000, B11000000,
  B00000001, B11000000,
  B00000001, B11000000,
  B00000011, B11100000,
  B11110011, B11100000,
  B11111110, B11111000,
  B01111110, B11111111,
  B00110011, B10011111,
  B00011111, B11111100,
  B00001101, B01110000,
  B00011011, B10100000,
  B00111111, B11100000,
  B00111111, B11110000,
  B01111100, B11110000,
  B01110000, B01110000,
  B00000000, B00110000
};

const int sensorPin = A0; 
float sensorValue;
float voltageOut;
float temperatureC;
float temperatureF;
int count;

void setup() {
  // put your setup code here, to run once:
  pinMode(ledpin, OUTPUT);  
  pinMode(powerpin, OUTPUT); 
  digitalWrite(powerpin, HIGH);
  pinMode(motionsensor, INPUT);
  pinMode(trigPin, OUTPUT); 
  pinMode(echoPin, INPUT); 
  Serial.begin(9600);
  
  delay(250); // wait for the OLED to power up
  display.begin(i2c_Address, true); // Address 0x3C default

  //startup screen code
  display.clearDisplay();
  display.display();
  for(int i = 0; i<64; i++){
  display.fillCircle(display.width() / 2, display.height() / 2, i, SH110X_WHITE);
  display.display();
  }

  for(int i = 0; i<56; i++){
  display.fillCircle(display.width() / 2, display.height() / 2, i, SH110X_BLACK);
  display.display();
  delay(1);
  }
  display.setTextSize(2);
  display.setTextColor(SH110X_WHITE);
  display.setCursor(24, 20);
  display.println("M.I.T.H");
  display.display();
  display.setTextSize(1);
  display.setCursor(31,36);
  display.println("Industries");
  display.display();
  delay(3000);
  
  display.clearDisplay();
  display.display();
}

int tempread(){ 
  sensorValue = analogRead(sensorPin);
  voltageOut = (sensorValue * 5000) / 1024;  
  temperatureF = voltageOut / 10;
  //if you want to read your temperature in C, uncomment the bellow code and comment out the above code. change return temperatureF to return temperatureC
  //temperatureC = (temperatureF - 32.0)*(5.0/9.0);
  return temperatureF;
}

String distanceread(){
  long duration; 
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2); 
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW); 
  duration = pulseIn(echoPin, HIGH); 
  distance = (duration * 0.034 / 2) * 0.0328084; 

  if(distance > 10) {
    return "<10";
  }
  else if(distance < 10) {
    return String(distance);
  }
}

void LEDfade() 
{
  //Fading the LED
  for(int i=0; i<255; i++){
    analogWrite(ledpin, i);
    delay(5);
  } 

  for(int i=255; i>0; i--){
    analogWrite(ledpin, i);
    delay(5);
  }
}

void loop() {
  
  if(count < 10) {
    
    digitalWrite(powerpin, HIGH);
    String dist = (String(distanceread()) + "ft");
    String temp = (String(tempread()) + "F"); //to change display to C change "F" to "C" 
    //Serial.begin(9600);
    display.setTextSize(4.1);
    display.setTextColor(SH110X_WHITE);
    display.setCursor(0, 0);
    
    display.println(dist);
    display.println(temp);
    display.display();
    LEDfade();
  }
  else if(count > 10){
    digitalWrite(powerpin, LOW);
    digitalWrite(ledpin, LOW);
    display.display();
    display.clearDisplay();
    
  }

  if(digitalRead(motionsensor) == HIGH){
    count = 0;
  }
  else if(digitalRead(motionsensor)== LOW){
    count++;
  }
  delay(1000);
  display.clearDisplay();
  Serial.println(count);


}
